@@ -141,10 +141,10 @@ class Renderer(base.Renderer):
                 else:
                     return leadMedia.getURL()
             else:
-                return "Error no media found in %s"%item.title
+                return None
         else:
             #TODO: Add lead image support and News Item Image support
-            return "Error no structural folder"
+            return None
 
     @memoize
     def results(self):
@@ -155,18 +155,29 @@ class Renderer(base.Renderer):
 
     def _standard_results(self):
         results = []
+        finalResults =[]
         collection = self.collection()
         if collection is not None:
             limit = self.data.limit
             if limit and limit > 0:
+                highLimit = limit + 10
                 # pass on batching hints to the catalog
-                results = collection.queryCatalog(batch=True, b_size=limit)
+                results = collection.queryCatalog(batch=True, b_size=highLimit)
                 results = results._sequence
             else:
                 results = collection.queryCatalog()
             if limit and limit > 0:
-                results = results[:limit]
-        return results
+                highLimit = limit + 10
+                results = results[:highLimit]
+            
+            for result in results:
+                if self.get_image(result) is not None:
+                    finalResults.append(result)
+                
+        if self.data.limit:
+            return finalResults[:self.data.limit]
+        else:
+            return finalResults
 
     def _random_results(self):
         # intentionally non-memoized
